==> huaweicloudsdkiam-3.0.52-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/update_user_information_option.py <==
# coding: utf-8

import re
import six





class UpdateUserInformationOption:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'email': 'str',
        'mobile': 'str'
    }

    attribute_map = {
        'email': 'email',
        'mobile': 'mobile'
    }

    def __init__(self, email=None, mobile=None):
        """UpdateUserInformationOption - a model defined in huaweicloud sdk"""
        
        

        self._email = None
        self._mobile = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if mobile is not None:
            self.mobile = mobile

    @property
    def email(self):
        """Gets the email of this UpdateUserInformationOption.

        IAM用户的新邮箱，符合邮箱格式，长度小于等于255字符。

        :return: The email of this UpdateUserInformationOption.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UpdateUserInformationOption.

        IAM用户的新邮箱，符合邮箱格式，长度小于等于255字符。

        :param email: The email of this UpdateUserInformationOption.
        :type: str
        """
        self._email = email

    @property
    def mobile(self):
        """Gets the mobile of this UpdateUserInformationOption.

        IAM用户的国家码+新手机号，手机号为纯数字，长度小于等于32字符。

        :return: The mobile of this UpdateUserInformationOption.
        :rtype: str
        """
        return self._mobile

    @mobile.setter
    def mobile(self, mobile):
        """Sets the mobile of this UpdateUserInformationOption.

        IAM用户的国家码+新手机号，手机号为纯数字，长度小于等于32字符。

        :param mobile: The mobile of this UpdateUserInformationOption.
        :type: str
        """
        self._mobile = mobile

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateUserInformationOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.0.54-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/update_user_information_option.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateUserInformationOption:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'email': 'str',
        'mobile': 'str'
    }

    attribute_map = {
        'email': 'email',
        'mobile': 'mobile'
    }

    def __init__(self, email=None, mobile=None):
        """UpdateUserInformationOption - a model defined in huaweicloud sdk"""
        
        

        self._email = None
        self._mobile = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if mobile is not None:
            self.mobile = mobile

    @property
    def email(self):
        """Gets the email of this UpdateUserInformationOption.

        IAM用户的新邮箱，符合邮箱格式，长度小于等于255字符。

        :return: The email of this UpdateUserInformationOption.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UpdateUserInformationOption.

        IAM用户的新邮箱，符合邮箱格式，长度小于等于255字符。

        :param email: The email of this UpdateUserInformationOption.
        :type: str
        """
        self._email = email

    @property
    def mobile(self):
        """Gets the mobile of this UpdateUserInformationOption.

        IAM用户的国家码+新手机号，手机号为纯数字，长度小于等于32字符。

        :return: The mobile of this UpdateUserInformationOption.
        :rtype: str
        """
        return self._mobile

    @mobile.setter
    def mobile(self, mobile):
        """Sets the mobile of this UpdateUserInformationOption.

        IAM用户的国家码+新手机号，手机号为纯数字，长度小于等于32字符。

        :param mobile: The mobile of this UpdateUserInformationOption.
        :type: str
        """
        self._mobile = mobile

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateUserInformationOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
